from pycurl import Curl as Curl
from typing import Protocol, TypeVar

T_co = TypeVar('T_co', covariant=True)

class RequestProtocol(Protocol[T_co]):
    def configure_handle(self, handle: Curl) -> None: ...
    def has_response(self) -> bool: ...
    def response(self) -> T_co: ...
    def completed(self) -> T_co: ...
