import pycurl
from typing import IO

class Request:
    url: str
    destination: IO[bytes]
    def __init__(self, url: str, destination: IO[bytes]) -> None: ...
    def configure_handle(self, handle: pycurl.Curl) -> None: ...
    def has_response(self) -> bool: ...
    def response(self) -> None: ...
    def completed(self) -> None: ...
